/*
 * skillchains-db.js
 *
 * Copyright (c) 2004 by Daniel Potter.  All rights reserved.
 *
 * This file is part of the FFXI Skillchains JS Library.
 *
 * The FFXI Skillchains JS Library is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The FFXI Skillchains JS Library is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the FFXI Skillchains JS Library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA  02111-1307  USA
 *
 * This file defines the database of skills and avatars.
 */

// Define the various elements

var EARTH = new Element("earth");
var THUNDER = new Element("thunder");
var WATER = new Element("water");
var FIRE = new Element("fire");
var ICE = new Element("ice");
var WIND = new Element("wind");
var LIGHT = new Element("light");
var DARK = new Element("dark");

// NOTE: These are not *really* elements.  They mark the various Ultimate
// Renkeis.  Certain weapon skills, instead of having an element, form
// the ultimate renkei.  These mark those weapon skills.

var UE_FRAGMENTATION = new Element("ue.fragmentation", "ufragmentation");
var UE_FUSION = new Element("ue.fusion", "ufusion");
var UE_GRAVITATION = new Element("ue.gravitation", "ugravitation");
var UE_DISTORTION = new Element("ue.distortion", "udistortion");

// Create the chains, now

// Level 1 chains:
var SCISSION = new Chain("scission", "scission", 1, EARTH);
var IMPACTION = new Chain("impaction", "impaction", 1, THUNDER);
var REVERBERATION = new Chain("reverberation", "reverberation", 1, WATER);
var LIQUEFACTION = new Chain("liquefaction", "liquefaction", 1, FIRE);
var INDURATION = new Chain("induration", "induration", 1, ICE);
var DETONATION = new Chain("detonation", "detonation", 1, WIND);
var TRANSFIXION = new Chain("transfixion", "transfixion", 1, LIGHT);
var COMPRESSION = new Chain("compression", "compression", 1, DARK);

// Level 2 chains:
var GRAVITATION = new Chain("gravitation", "gravitation", 2, DARK, EARTH);
var DISTORTION = new Chain("distortion", "distortion", 2, WATER, ICE);
var FUSION = new Chain("fusion", "fusion", 2, FIRE, LIGHT);
var FRAGMENTATION = new Chain("fragmentation", "fragmentation", 2, THUNDER, WIND);

// Level 3 chains:

var ULTIMATE_LIGHT = new Chain("ultimate.light", "ultlight", 3, FIRE, LIGHT, THUNDER, WIND);
var ULTIMATE_DARKNESS = new Chain("ultimate.darkness", "ultdark", 3, EARTH, DARK, WATER, ICE);

// Link the elements now to describe how chains can be formed

EARTH.addChain(REVERBERATION, WATER);
EARTH.addChain(DETONATION, WIND);
EARTH.addChain(LIQUEFACTION, FIRE);
// NOTE: only when coming from Distortion
EARTH.addChain(FUSION, UE_FUSION, DISTORTION);
// NOTE: only when coming from Distortion
EARTH.addChain(ULTIMATE_DARKNESS, UE_GRAVITATION, DISTORTION);
THUNDER.addChain(LIQUEFACTION, FIRE);
THUNDER.addChain(DETONATION, WIND);
// NOTE: only when coming from Fusion
THUNDER.addChain(GRAVITATION, UE_GRAVITATION, FUSION);
// NOTE: only when coming from Fusion
THUNDER.addChain(ULTIMATE_LIGHT, UE_FRAGMENTATION, FUSION);
WATER.addChain(INDURATION, ICE);
WATER.addChain(IMPACTION, THUNDER);
// NOTE: only when coming from Fragmentation
WATER.addChain(DISTORTION, UE_DISTORTION, FRAGMENTATION);
// NOTE: only when coming from Fragmentation
WATER.addChain(ULTIMATE_LIGHT, UE_FUSION, FRAGMENTATION);
FIRE.addChain(SCISSION, EARTH);
FIRE.addChain(FUSION, THUNDER);
ICE.addChain(FRAGMENTATION, WATER);
ICE.addChain(IMPACTION, THUNDER);
ICE.addChain(COMPRESSION, DARK);
WIND.addChain(SCISSION, EARTH);
WIND.addChain(GRAVITATION, DARK);
LIGHT.addChain(REVERBERATION, WATER);
LIGHT.addChain(DISTORTION, EARTH);
LIGHT.addChain(COMPRESSION, DARK);
DARK.addChain(DETONATION, WIND);
DARK.addChain(TRANSFIXION, LIGHT);
// NOTE: only when coming from Gravitation
DARK.addChain(FRAGMENTATION, UE_FRAGMENTATION, GRAVITATION);
// NOTE: only when coming from Gravitation
DARK.addChain(ULTIMATE_DARKNESS, UE_DISTORTION, GRAVITATION);

UE_FUSION.addChain(GRAVITATION, UE_GRAVITATION);
UE_FUSION.addChain(ULTIMATE_LIGHT, UE_FRAGMENTATION);
UE_FRAGMENTATION.addChain(DISTORTION, UE_DISTORTION);
UE_FRAGMENTATION.addChain(ULTIMATE_LIGHT, UE_FUSION);
UE_DISTORTION.addChain(FUSION, UE_FUSION);
UE_DISTORTION.addChain(ULTIMATE_DARKNESS, UE_GRAVITATION);
UE_GRAVITATION.addChain(FRAGMENTATION, UE_FRAGMENTATION);
UE_GRAVITATION.addChain(ULTIMATE_DARKNESS, UE_DISTORTION);

// Create the jobs:

var WARRIOR = new Job("warrior");
var THIEF = new Job("thief");
var MONK = new Job("monk");
var RED_MAGE = new Job("red.mage");
var WHITE_MAGE = new Job("white.mage");
var BLACK_MAGE = new Job("black.mage");
var BARD = new Job("bard");
var BEASTMASTER = new Job("beastmaster");
var DARK_KNIGHT = new Job("dark.knight");
var DRAGOON = new Job("dragoon");
var NINJA = new Job("ninja");
var PALADIN = new Job("paladin");
var RANGER = new Job("ranger");
var SAMURAI = new Job("samurai");
var SUMMONER = new Job("summoner");

// OK, next the weapon classes...

var ARCHERY = new Weapon("archery", [RANGER], [RANGER]);
var BOW = ARCHERY; // alias
var AXE = new Weapon("axe", [WARRIOR, BEASTMASTER, DARK_KNIGHT], [WARRIOR, BEASTMASTER]);
var CLUB = new Weapon("club", [WARRIOR, PALADIN, WHITE_MAGE, DARK_KNIGHT, SAMURAI], [WHITE_MAGE]);
var DAGGER = new Weapon("dagger", [THIEF, RED_MAGE, BARD, RANGER, NINJA], [THIEF]);
var GREAT_AXE = new Weapon("great.axe", [WARRIOR, DARK_KNIGHT], [WARRIOR]);
var GREAT_KATANA = new Weapon("great.katana", null, [SAMURAI]);
var GREAT_SWORD = new Weapon("great.sword", [WARRIOR, PALADIN, DARK_KNIGHT], [PALADIN, DARK_KNIGHT]);
var HAND_TO_HAND = new Weapon("hand.to.hand", [MONK], [MONK]);
var KATANA = new Weapon("katana", null, [NINJA]);
var MARKSMANSHIP = new Weapon("marksmanship", [RANGER], [RANGER]);
var GUN = MARKSMANSHIP; // alias
var SCYTHE = new Weapon("scythe", [WARRIOR, DARK_KNIGHT], [DARK_KNIGHT]);
var POLEARM = new Weapon("polearm", [WARRIOR, PALADIN, DRAGOON], [DRAGOON]);
var SPEAR = POLEARM; // alias
var STAFF = new Weapon("staff", [PALADIN, MONK, WARRIOR, WHITE_MAGE], null);
var SWORD = new Weapon("sword", [PALADIN, WARRIOR, DARK_KNIGHT], [PALADIN]);

// Now the avatars
var CARBUNCLE = new Weapon("carbuncle", null, null, true);
var GARUDA = new Weapon("garuda", null, null, true);
var IFRIT = new Weapon("ifrit", null, null, true);
var LEVIATHAN = new Weapon("leviathan", null, null, true);
var RAMUH = new Weapon("ramuh", null, null, true);
var SHIVA = new Weapon("shiva", null, null, true);
var TITAN = new Weapon("titan", null, null, true);
var FENRIR = new Weapon("fenrir", null, null, true);

// Now, the skills themselves!
//
// This list is currently based on Adennak's Renkei chart.
// <http://www.adennak.com/renkei.html>

// ARCHERY:
//  EX/SP - RNG
ARCHERY.addSkill(new WeaponSkill("flaming.arrow", 10, WS_EX, FIRE, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill("piercing.arrow", 40, WS_EX, WATER, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill("dulling.arrow", 80, WS_EX, FIRE, LIGHT)); // EX
ARCHERY.addSkill(new WeaponSkill("sidewinder", 175, WS_EX, WATER, LIGHT, WIND)); // EX
ARCHERY.addSkill(new WeaponSkill("blast.arrow", 200, WS_SP, ICE, LIGHT)); // SP
ARCHERY.addSkill(new WeaponSkill("arching.arrow", 225, WS_SP, UE_FUSION)); // SP
ARCHERY.addSkill(new WeaponSkill("emperial.arrow", 250, WS_EX, UE_FUSION, LIGHT)); // EX
// AXE:
//  EX - WAR/BST/DRK
//  SP - WAR/BST
AXE.addSkill(new WeaponSkill("raging.axe", 10, WS_NORMAL, WIND, THUNDER));
AXE.addSkill(new WeaponSkill("smash.axe", 40, WS_NORMAL, ICE, WATER));
AXE.addSkill(new WeaponSkill("gale.axe", 70, WS_NORMAL, WIND));
AXE.addSkill(new WeaponSkill("avalanche.axe", 100, WS_NORMAL, EARTH, THUNDER));
AXE.addSkill(new WeaponSkill("spinning.axe", 150, WS_EX, FIRE, EARTH, THUNDER)); // EX
AXE.addSkill(new WeaponSkill("rampage", 175, WS_NORMAL, EARTH));
AXE.addSkill(new WeaponSkill("calamity", 200, WS_SP, EARTH, THUNDER)); // SP
AXE.addSkill(new WeaponSkill("mistral.axe", 225, WS_SP, UE_FUSION)); // SP
AXE.addSkill(new WeaponSkill("decimation", 240, WS_NORMAL, UE_FUSION, WATER));
// CLUB:
//  EX - WAR/PLD/WHM/DRK/SAM
//  SP - WHM
CLUB.addSkill(new WeaponSkill("shining.strike", 10, WS_NORMAL, THUNDER));
CLUB.addSkill(new WeaponSkill("seraph.strike", 40, WS_EX, THUNDER)); // EX
CLUB.addSkill(new WeaponSkill("brainshaker", 70, WS_NORMAL, WATER));
CLUB.addSkill(new WeaponSkill("star.light", 100, WS_NORMAL));
CLUB.addSkill(new WeaponSkill("moon.light", 100, WS_EX)); // EX
CLUB.addSkill(new WeaponSkill("skullbreaker", 150, WS_NORMAL, ICE, WATER));
CLUB.addSkill(new WeaponSkill("true.strike", 175, WS_NORMAL, WIND, THUNDER));
CLUB.addSkill(new WeaponSkill("judgment", 200, WS_EX, THUNDER)); // EX
CLUB.addSkill(new WeaponSkill("hexa.strike", 220, WS_SP, UE_FUSION)); // SP
CLUB.addSkill(new WeaponSkill("black.halo", 230, WS_SP, UE_FRAGMENTATION, DARK)); // SP
// DAGGER:
//  EX - THF/RDM/BRD/RNG/NIN
//  SP - THF
DAGGER.addSkill(new WeaponSkill("wasp.sting", 10, WS_NORMAL, EARTH));
DAGGER.addSkill(new WeaponSkill("gust.slash", 40, WS_NORMAL, WIND));
DAGGER.addSkill(new WeaponSkill("shadowstich", 70, WS_NORMAL, WATER));
DAGGER.addSkill(new WeaponSkill("viper.bite", 100, WS_EX, EARTH)); // EX
DAGGER.addSkill(new WeaponSkill("cyclone", 125, WS_EX, WIND, THUNDER)); // EX
DAGGER.addSkill(new WeaponSkill("energy.steal", 150, WS_NORMAL));
DAGGER.addSkill(new WeaponSkill("energy.drain", 175, WS_EX)); // EX
DAGGER.addSkill(new WeaponSkill("dancing.edge", 200, WS_SP, EARTH, WIND)); // SP
DAGGER.addSkill(new WeaponSkill("shark.bite", 225, WS_SP, UE_FRAGMENTATION)); // SP
DAGGER.addSkill(new WeaponSkill("evisceration", 250, WS_NORMAL, UE_GRAVITATION, LIGHT));
// GREAT AXE:
//  EX - WAR/DRK
//  SP - WAR
GREAT_AXE.addSkill(new WeaponSkill("shield.break", 10, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill("iron.tempest", 40, WS_NORMAL, EARTH /*, THUNDER ? */));
GREAT_AXE.addSkill(new WeaponSkill("strumwind", 70, WS_EX, WATER, EARTH)); // EX
GREAT_AXE.addSkill(new WeaponSkill("armor.break", 100, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill("keen.edge", 150, WS_NORMAL, DARK));
GREAT_AXE.addSkill(new WeaponSkill("weapon.break", 175, WS_NORMAL, THUNDER));
GREAT_AXE.addSkill(new WeaponSkill("raging.rush", 200, WS_SP, ICE, WATER)); // SP
GREAT_AXE.addSkill(new WeaponSkill("full.break", 225, WS_SP, UE_DISTORTION)); // SP
GREAT_AXE.addSkill(new WeaponSkill("steel.cyclone", 240, WS_NORMAL, UE_DISTORTION, WIND));
// GREAT KATANA:
//  SP - SAM
GREAT_KATANA.addSkill(new WeaponSkill("tachi.enpi", 10, WS_NORMAL, LIGHT, EARTH));
GREAT_KATANA.addSkill(new WeaponSkill("tachi.hobaku", 30, WS_NORMAL, ICE));
GREAT_KATANA.addSkill(new WeaponSkill("tachi.goten", 70, WS_NORMAL, LIGHT, THUNDER));
GREAT_KATANA.addSkill(new WeaponSkill("tachi.kagero", 100, WS_NORMAL, FIRE));
GREAT_KATANA.addSkill(new WeaponSkill("tachi.jinpu", 150, WS_NORMAL, EARTH, WIND));
GREAT_KATANA.addSkill(new WeaponSkill("tachi.koki", 175, WS_NORMAL, WATER, THUNDER)); // elements may be reversed on this
GREAT_KATANA.addSkill(new WeaponSkill("tachi.yukikaze", 200, WS_SP, ICE, WIND)); // SP
GREAT_KATANA.addSkill(new WeaponSkill("tachi.gekko", 225, WS_SP, UE_DISTORTION, WATER)); // SP
GREAT_KATANA.addSkill(new WeaponSkill("tachi.kasha", 250, WS_NORMAL, UE_FUSION, DARK));
// GREAT SWORD
//  EX - WAR/PLD/DRK
//  SP - PLD/DRK
GREAT_SWORD.addSkill(new WeaponSkill("hard.slash", 10, WS_NORMAL, EARTH));
GREAT_SWORD.addSkill(new WeaponSkill("power.slash", 30, WS_NORMAL, LIGHT));
GREAT_SWORD.addSkill(new WeaponSkill("frostbite", 70, WS_NORMAL, ICE));
GREAT_SWORD.addSkill(new WeaponSkill("freezebite", 100, WS_EX, ICE, WIND)); // EX
GREAT_SWORD.addSkill(new WeaponSkill("shockwave", 150, WS_NORMAL, WATER));
GREAT_SWORD.addSkill(new WeaponSkill("crescent.moon", 175, WS_NORMAL, EARTH));
GREAT_SWORD.addSkill(new WeaponSkill("sickle.moon", 200, WS_SP, EARTH, THUNDER)); // SP
// The following two were listed as Gravitation
GREAT_SWORD.addSkill(new WeaponSkill("spinning.slash", 225, WS_SP, UE_FRAGMENTATION)); // SP
GREAT_SWORD.addSkill(new WeaponSkill("ground.strike", 250, WS_NORMAL, UE_FRAGMENTATION, UE_DISTORTION));
// HAND TO HAND
//  EX - MNK
//  SP - MNK
HAND_TO_HAND.addSkill(new WeaponSkill("combo", 10, WS_NORMAL, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill("shoulder.tackle", 40, WS_NORMAL, WATER, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill("one.inch.punch", 75, WS_EX, DARK)); // EX
HAND_TO_HAND.addSkill(new WeaponSkill("backhand.blow", 100, WS_NORMAL, WIND));
HAND_TO_HAND.addSkill(new WeaponSkill("raging.fists", 125, WS_EX, THUNDER)); // EX
HAND_TO_HAND.addSkill(new WeaponSkill("spinning.attack", 150, WS_NORMAL, FIRE, THUNDER));
HAND_TO_HAND.addSkill(new WeaponSkill("howling.fist", 200, WS_SP, LIGHT, THUNDER)); // SP
HAND_TO_HAND.addSkill(new WeaponSkill("dragon.kick", 225, WS_SP, UE_FRAGMENTATION)); // SP
HAND_TO_HAND.addSkill(new WeaponSkill("ashuran.fist", 250, WS_SP, UE_GRAVITATION, FIRE)); // SP
// KATANA
//  SP - NIN
KATANA.addSkill(new WeaponSkill("blade.rin", 10, WS_NORMAL, LIGHT));
KATANA.addSkill(new WeaponSkill("blade.retsu", 30, WS_NORMAL, EARTH));
KATANA.addSkill(new WeaponSkill("blade.teki", 70, WS_NORMAL, WATER));
KATANA.addSkill(new WeaponSkill("blade.to", 100, WS_NORMAL, ICE, WIND));
KATANA.addSkill(new WeaponSkill("blade.chi", 150, WS_NORMAL, LIGHT, THUNDER));
KATANA.addSkill(new WeaponSkill("blade.ei", 175, WS_NORMAL, DARK));
KATANA.addSkill(new WeaponSkill("blade.jin", 200, WS_SP, WIND, THUNDER)); // SP
KATANA.addSkill(new WeaponSkill("blade.ten", 225, WS_SP, UE_GRAVITATION)); // SP
KATANA.addSkill(new WeaponSkill("blade.ku", 250, WS_SP, UE_GRAVITATION, LIGHT)); // SP
// MARKSMANSHIP
//  EX - RNG
//  SP - RNG
MARKSMANSHIP.addSkill(new WeaponSkill("hot.shot", 10, WS_EX, FIRE, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill("split.shot", 40, WS_EX, WATER, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill("sniper.shot", 80, WS_EX, FIRE, LIGHT)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill("slug.shot", 175, WS_EX, WATER, LIGHT, WIND)); // EX
MARKSMANSHIP.addSkill(new WeaponSkill("blast.shot", 200, WS_SP, ICE, LIGHT)); // SP
MARKSMANSHIP.addSkill(new WeaponSkill("heavy.shot", 225, WS_SP, UE_FUSION)); // SP
MARKSMANSHIP.addSkill(new WeaponSkill("detonator", 250, WS_NORMAL, UE_FUSION, LIGHT));
// SCYTHE
//  EX - WAR/DRK
//  SP - DRK
SCYTHE.addSkill(new WeaponSkill("slice", 10, WS_NORMAL, EARTH));
SCYTHE.addSkill(new WeaponSkill("dark.harvest", 40, WS_NORMAL, WATER));
SCYTHE.addSkill(new WeaponSkill("shadow.of.death", 70, WS_EX, ICE, WATER)); // EX
SCYTHE.addSkill(new WeaponSkill("nightmare.scythe", 100, WS_NORMAL, DARK, EARTH));
SCYTHE.addSkill(new WeaponSkill("spinning.scythe", 125, WS_NORMAL, WATER, EARTH));
SCYTHE.addSkill(new WeaponSkill("vorpal.scythe", 150, WS_NORMAL, LIGHT, EARTH));
SCYTHE.addSkill(new WeaponSkill("guillotine", 200, WS_SP, ICE)); // SP
SCYTHE.addSkill(new WeaponSkill("cross.reaper", 225, WS_SP, UE_DISTORTION)); // SP
SCYTHE.addSkill(new WeaponSkill("spiral.hell", 240, WS_NORMAL, UE_DISTORTION, EARTH));
// SPEAR
//  EX - WAR/PLD/DRG
//  SP - DRG
SPEAR.addSkill(new WeaponSkill("double.thrust", 10, WS_NORMAL, LIGHT));
SPEAR.addSkill(new WeaponSkill("thunder.thrust", 30, WS_NORMAL, LIGHT, THUNDER));
SPEAR.addSkill(new WeaponSkill("raiden.thrust", 70, WS_EX, LIGHT, THUNDER)); // EX
SPEAR.addSkill(new WeaponSkill("leg.sweep", 100, WS_NORMAL, THUNDER));
SPEAR.addSkill(new WeaponSkill("penta.thrust", 150, WS_NORMAL, DARK));
SPEAR.addSkill(new WeaponSkill("vorpal.thrust", 175, WS_NORMAL, WATER, LIGHT));
SPEAR.addSkill(new WeaponSkill("skewer", 200, WS_SP, THUNDER, DARK, LIGHT)); // (Thunder was missing, possibly) SP
SPEAR.addSkill(new WeaponSkill("wheeling.thrust", 225, WS_SP, UE_FUSION)); // SP
SPEAR.addSkill(new WeaponSkill("impulse.drive", 240, WS_NORMAL, UE_GRAVITATION, ICE /* ? */));
// STAFF
//  EX - PLD/MNK/WAR/WHM
STAFF.addSkill(new WeaponSkill("heavy.swing", 10, WS_NORMAL, THUNDER));
STAFF.addSkill(new WeaponSkill("rock.crusher", 40, WS_NORMAL, THUNDER));
STAFF.addSkill(new WeaponSkill("earth.crusher", 70, WS_EX, WIND, THUNDER)); // EX
STAFF.addSkill(new WeaponSkill("star.burst", 100, WS_NORMAL, DARK, WATER));
STAFF.addSkill(new WeaponSkill("sun.burst", 150, WS_EX, DARK, WATER)); // EX
STAFF.addSkill(new WeaponSkill("shell.crusher", 175, WS_NORMAL, WIND, THUNDER));
STAFF.addSkill(new WeaponSkill("full.swing", 200, WS_NORMAL, FIRE, THUNDER));
STAFF.addSkill(new WeaponSkill("spirit.taker", 215, WS_NORMAL)); // Doesn't chain?  Used to be THUNDER, FIRE
STAFF.addSkill(new WeaponSkill("retribution", 230, WS_NORMAL, UE_GRAVITATION, WATER));
// SWORD
//  EX - PLD/WAR/DRK
//  SP - PLD
SWORD.addSkill(new WeaponSkill("fast.blade", 10, WS_NORMAL, EARTH));
SWORD.addSkill(new WeaponSkill("burning.blade", 30, WS_NORMAL, FIRE));
SWORD.addSkill(new WeaponSkill("red.lotus.blade", 50, WS_EX, FIRE, WIND)); // EX
SWORD.addSkill(new WeaponSkill("flat.blade", 75, WS_NORMAL, THUNDER));
SWORD.addSkill(new WeaponSkill("shining.blade", 100, WS_NORMAL, EARTH));
SWORD.addSkill(new WeaponSkill("seraph.blade", 125, WS_EX, EARTH)); // EX
SWORD.addSkill(new WeaponSkill("circle.blade", 150, WS_NORMAL, WATER, THUNDER));
SWORD.addSkill(new WeaponSkill("spirits.within", 175, WS_NORMAL));
SWORD.addSkill(new WeaponSkill("vorpal.blade", 200, WS_EX, EARTH, THUNDER)); // EX
SWORD.addSkill(new WeaponSkill("swift.blade", 225, WS_SP, UE_GRAVITATION)); // SP
SWORD.addSkill(new WeaponSkill("savage.blade", 240, WS_NORMAL, UE_FRAGMENTATION, EARTH));

// AVATAR BLOOD PACTS
// The current list of blood pacts taken from:
// <http://www.ukg.pwp.blueyonder.co.uk/avatar.htm>
// NOTE: The avatar elemental data is still be compiled.
// RIGHT NOW the elements placed on the basic weapon skills are, shall we say,
// complete and total BS.  It's just guesses.
//
// Also, a new flag WS_BURST has been added to mark skills that cannot
// participate in a skillchain but can magic burst.  (Those are guesses too.)

CARBUNCLE.addSkill(new WeaponSkill("searing.light", 1, WS_AVATAR | WS_ASTRALFLOW));
CARBUNCLE.addSkill(new WeaponSkill("healing.ruby", 1, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill("poison.nails", 5, WS_AVATAR, LIGHT));
CARBUNCLE.addSkill(new WeaponSkill("shining.ruby", 24, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill("glittering.ruby", 44, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill("meteorite", 55, WS_AVATAR));
CARBUNCLE.addSkill(new WeaponSkill("healing.ruby.2", 65, WS_AVATAR));

GARUDA.addSkill(new WeaponSkill("aerial.blast", 1, WS_AVATAR | WS_ASTRALFLOW));
GARUDA.addSkill(new WeaponSkill("claw", 1, WS_AVATAR, WIND));
GARUDA.addSkill(new WeaponSkill("aero.2", 10, WS_AVATAR | WS_BURST, WIND));
GARUDA.addSkill(new WeaponSkill("aerial.armor", 25, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill("whispering.wind", 36, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill("hastega", 48, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill("aero.4", 60, WS_AVATAR | WS_BURST, WIND));
GARUDA.addSkill(new WeaponSkill("predator.claw", 70, WS_AVATAR));
GARUDA.addSkill(new WeaponSkill("wind.blade", 75, WS_AVATAR));

TITAN.addSkill(new WeaponSkill("rage.of.the.earth", 1, WS_AVATAR | WS_ASTRALFLOW));
TITAN.addSkill(new WeaponSkill("rock.throw", 1, WS_AVATAR, EARTH));
TITAN.addSkill(new WeaponSkill("stone.2", 10, WS_AVATAR | WS_BURST, EARTH));
TITAN.addSkill(new WeaponSkill("rock.buster", 21, WS_AVATAR, WATER));
TITAN.addSkill(new WeaponSkill("megalith.throw", 35, WS_AVATAR, ICE));
TITAN.addSkill(new WeaponSkill("earthen.ward", 46, WS_AVATAR));
TITAN.addSkill(new WeaponSkill("stone.4", 60, WS_AVATAR | WS_BURST, EARTH));
TITAN.addSkill(new WeaponSkill("mountain.crash", 70, WS_AVATAR));
TITAN.addSkill(new WeaponSkill("ground.fury", 75, WS_AVATAR));

SHIVA.addSkill(new WeaponSkill("diamond.dust", 1, WS_AVATAR | WS_ASTRALFLOW));
SHIVA.addSkill(new WeaponSkill("axe.kick", 1, WS_AVATAR, ICE));
SHIVA.addSkill(new WeaponSkill("blizzard.2", 10, WS_AVATAR | WS_BURST, ICE));
SHIVA.addSkill(new WeaponSkill("frost.armor", 28, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill("sleepga", 40, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill("double.slap", 50, WS_AVATAR, EARTH));
SHIVA.addSkill(new WeaponSkill("blizzard.4", 60, WS_AVATAR | WS_BURST, ICE));
SHIVA.addSkill(new WeaponSkill("rush", 70, WS_AVATAR));
SHIVA.addSkill(new WeaponSkill("heavenly.strike", 75, WS_AVATAR));

IFRIT.addSkill(new WeaponSkill("inferno", 1, WS_AVATAR | WS_ASTRALFLOW));
IFRIT.addSkill(new WeaponSkill("punch", 1, WS_AVATAR, FIRE)); // (this one is actually known)
IFRIT.addSkill(new WeaponSkill("fire.2", 10, WS_AVATAR | WS_BURST, FIRE));
IFRIT.addSkill(new WeaponSkill("burning.strike", 23, WS_AVATAR, THUNDER));
IFRIT.addSkill(new WeaponSkill("double.punch", 30, WS_AVATAR, DARK));
IFRIT.addSkill(new WeaponSkill("crimson.howl", 38, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill("fire.4", 60, WS_AVATAR | WS_BURST, FIRE));
IFRIT.addSkill(new WeaponSkill("flame.crush", 70, WS_AVATAR));
IFRIT.addSkill(new WeaponSkill("meteor.strike", 75, WS_AVATAR));

RAMUH.addSkill(new WeaponSkill("judgement.bolt", 1, WS_AVATAR | WS_ASTRALFLOW));
RAMUH.addSkill(new WeaponSkill("shock.strike", 1, WS_AVATAR, THUNDER));
RAMUH.addSkill(new WeaponSkill("thunder.2", 10, WS_AVATAR | WS_BURST, THUNDER));
RAMUH.addSkill(new WeaponSkill("thunderspark", 19, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill("shockwave", 31, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill("lightening.armor", 42, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill("thunder.4", 60, WS_AVATAR | WS_BURST, THUNDER));
RAMUH.addSkill(new WeaponSkill("chaotic.strike", 70, WS_AVATAR));
RAMUH.addSkill(new WeaponSkill("thunder.storm", 75, WS_AVATAR));

LEVIATHAN.addSkill(new WeaponSkill("tidal.wave", 1, WS_AVATAR | WS_ASTRALFLOW));
LEVIATHAN.addSkill(new WeaponSkill("barracuda.dive", 1, WS_AVATAR, WATER));
LEVIATHAN.addSkill(new WeaponSkill("water.2", 10, WS_AVATAR | WS_BURST, WATER));
LEVIATHAN.addSkill(new WeaponSkill("tail.whip", 26, WS_AVATAR, WIND));
LEVIATHAN.addSkill(new WeaponSkill("slowga", 33, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill("spring.water", 47, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill("water.4", 60, WS_AVATAR | WS_BURST, WATER));
LEVIATHAN.addSkill(new WeaponSkill("spinning.dive", 70, WS_AVATAR));
LEVIATHAN.addSkill(new WeaponSkill("grand.fall", 75, WS_AVATAR));

FENRIR.addSkill(new WeaponSkill("rush", 1, WS_AVATAR | WS_ASTRALFLOW));
FENRIR.addSkill(new WeaponSkill("moonlit.charge", 5, WS_AVATAR, DARK));
FENRIR.addSkill(new WeaponSkill("crescent.fang", 10, WS_AVATAR, LIGHT));
FENRIR.addSkill(new WeaponSkill("lunar.cry", 24, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill("lunar.roar", 32, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill("ecliptic.growl", 43, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill("ecliptic.howl", 54, WS_AVATAR));
FENRIR.addSkill(new WeaponSkill("ecliptic.bite", 65, WS_AVATAR));

// Finally, chuck all the data into a global object for easy reference.

var SkillChainDB = new Object();

SkillChainDB.jobs = [ WARRIOR, THIEF, MONK, RED_MAGE, WHITE_MAGE, BLACK_MAGE,
	BARD, BEASTMASTER, DARK_KNIGHT, DRAGOON, NINJA, PALADIN, RANGER,
	SAMURAI, SUMMONER ];
SkillChainDB.weapons = [ARCHERY, AXE, CLUB, DAGGER, GREAT_AXE, GREAT_KATANA,
	GREAT_SWORD, HAND_TO_HAND, KATANA, MARKSMANSHIP, SCYTHE, SPEAR,
	STAFF, SWORD];
SkillChainDB.avatars = [ CARBUNCLE, GARUDA, IFRIT, LEVIATHAN, RAMUH, SHIVA, TITAN, FENRIR ];
SkillChainDB.elements = [ FIRE, ICE, WIND, EARTH, THUNDER, WATER, LIGHT, DARK, UE_FRAGMENTATION, UE_FUSION, UE_GRAVITATION, UE_DISTORTION ];

// be kind and sort these for the users
SkillChainDB.jobs.sort(compareNames);
SkillChainDB.weapons.sort(compareNames);
SkillChainDB.avatars.sort(compareNames);

// Set the version number
SkillChainDB.majorVersion = 0;
SkillChainDB.minorVersion = 9;
SkillChainDB.buildVersion = 3;
